#!/bin/sh

set -ex

rm -rf /var/lib/mysql/*

/linuxcash/cash/bin/maintainer/dictionaries

echo "Setup MySQL8 server debconf"

echo "mysql-community-server mysql-community-server/root-pass password """ | debconf-set-selections
echo "mysql-community-server mysql-community-server/re-root-pass password """ | debconf-set-selections
echo "mysql-community-server mysql-server/default-auth-override select Use Legacy Authentication Method (Retain MySQL 5.x Compatibility)" | debconf-set-selections
echo "mysql-community-server mysql-server/data-dir select '/linuxcash/cash/data/mysql'" | debconf-set-selections

apt-get update
apt-get -o Dpkg::Options::="--force-overwrite" -o Dpkg::Options::="--force-confnew" -yq install artix-mysql8-config

echo "Create dictionaries dump 'dict.sql'"
WORKING_TABLES='migrate_version'
for VIEW in $(mysql --batch --skip-column-names -e "SELECT table_name FROM information_schema.tables WHERE table_type LIKE 'VIEW' AND table_schema = 'dictionaries'") ; do
    VIEW_TABLE=$(mysql --batch --skip-column-names -e "show create view \`$VIEW\`" dictionaries | sed -n "s/.*\($VIEW[1,2]*\).*/\1/p")
    WORKING_TABLES="$WORKING_TABLES $VIEW_TABLE"
done
mysqldump -c --compact --no-create-info --skip-triggers --skip-add-locks --skip-comments --replace dictionaries $WORKING_TABLES > dict.sql && echo " done"
sed -i 's/^REPLACE INTO `\([^0-9]\+\)[1-2]`/REPLACE INTO `\1`/' dict.sql
echo "Drop dictionaries database"
/linuxcash/cash/data/db/drop_dictionaries && echo " done"
/linuxcash/cash/data/db/update_db
echo "Restore dictionaries from dump"
mysql -f dictionaries < dict.sql
rm -f ./dict.sql
